Coverage for /home/chris/workspace/django-shop/shop/clientmodel/admin: 100.00%

# Coverage for /home/chris/workspace/django-shop/shop/clientmodel/admin : 100.00%

## 12 statements 12 run 0 missing 0 excluded 0 partial

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | #-*- coding: utf-8 -*- from django.contrib import admin from django.contrib.admin.options import ModelAdmin from shop.clientmodel.models import Client, Country, Address class ClientAdmin(ModelAdmin): pass admin.site.register(Client, ClientAdmin) class CountryAdmin(ModelAdmin): pass admin.site.register(Country, CountryAdmin) class AddressAdmin(ModelAdmin): pass admin.site.register(Address, AddressAdmin)